@@ -82,76 +82,6 @@ namespace cv {
 namespace dynafu {
 using namespace kinfu;
 
-Ptr<Params> Params::defaultParams()
-{
-    Params p;
-
-    p.frameSize = Size(640, 480);
-
-    float fx, fy, cx, cy;
-    fx = fy = 525.f;
-    cx = p.frameSize.width/2 - 0.5f;
-    cy = p.frameSize.height/2 - 0.5f;
-    p.intr = Matx33f(fx,  0, cx,
-                      0, fy, cy,
-                      0,  0,  1);
-
-    // 5000 for the 16-bit PNG files
-    // 1 for the 32-bit float images in the ROS bag files
-    p.depthFactor = 5000;
-
-    // sigma_depth is scaled by depthFactor when calling bilateral filter
-    p.bilateral_sigma_depth = 0.04f;  //meter
-    p.bilateral_sigma_spatial = 4.5; //pixels
-    p.bilateral_kernel_size = 7;     //pixels
-
-    p.icpAngleThresh = (float)(30. * CV_PI / 180.); // radians
-    p.icpDistThresh = 0.1f; // meters
-
-    p.icpIterations = {10, 5, 4};
-    p.pyramidLevels = (int)p.icpIterations.size();
-
-    p.tsdf_min_camera_movement = 0.f; //meters, disabled
-
-    p.volumeDims = Vec3i::all(512); //number of voxels
-
-    float volSize = 3.f;
-    p.voxelSize = volSize/512.f; //meters
-
-    // default pose of volume cube
-    p.volumePose = Affine3f().translate(Vec3f(-volSize/2.f, -volSize/2.f, 0.5f));
-    p.tsdf_trunc_dist = 0.04f; //meters;
-    p.tsdf_max_weight = 64;   //frames
-
-    p.raycast_step_factor = 0.25f;  //in voxel sizes
-    // gradient delta factor is fixed at 1.0f and is not used
-    //p.gradient_delta_factor = 0.5f; //in voxel sizes
-
-    //p.lightPose = p.volume_pose.translation()/4; //meters
-    p.lightPose = Vec3f::all(0.f); //meters
-
-    // depth truncation is not used by default but can be useful in some scenes
-    p.truncateThreshold = 0.f; //meters
-
-    return makePtr<Params>(p);
-}
-
-Ptr<Params> Params::coarseParams()
-{
-    Ptr<Params> p = defaultParams();
-
-    p->icpIterations = {5, 3, 2};
-    p->pyramidLevels = (int)p->icpIterations.size();
-
-    float volSize = 3.f;
-    p->volumeDims = Vec3i::all(128); //number of voxels
-    p->voxelSize  = volSize/128.f;
-
-    p->raycast_step_factor = 0.75f;  //in voxel sizes
-
-    return p;
-}
-
 // T should be Mat or UMat
 template< typename T >
 class DynaFuImpl : public DynaFu
